        public {baseClassName}Builder<{categoryClassName}Builder, {schemaName}BlockBuilder, {schemaName}FileBuilder> enter{columnClassName}() {
            return new {baseClassName}BuilderImpl<>(CATEGORY_NAME, "{columnName}", this);
        }

