    /**
{columnDescription}
     * @return {baseClassName}
     */
    public {baseClassName} get{columnClassName}() {
        return new Delegating{baseClassName}(parentBlock.get{modifier}Column({aliases}));
    }

