    /**
{categoryDescription}
     * @return {categoryClassName}
     */
    public {categoryClassName} get{categoryClassName}() {
        return delegate.getCategory("{categoryName}", {categoryClassName}::new);
    }

