    public static class {categoryClassName}Builder extends {schemaName}CategoryBuilder {
        private static final String CATEGORY_NAME = "{categoryName}";

        public {categoryClassName}Builder({schemaName}BlockBuilder parent) {
            super(CATEGORY_NAME, parent);
        }

{columnEnters}
    }

